==> deltaspike-1.9.6-source-release.zip: deltaspike-1.9.6/deltaspike/modules/data/impl/src/test/java/org/apache/deltaspike/data/test/TransactionalTestCase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.deltaspike.data.test;

import javax.annotation.Resource;
import javax.inject.Inject;
import javax.persistence.EntityManager;
import javax.transaction.UserTransaction;

import org.apache.deltaspike.data.test.util.TestData;
import org.jboss.arquillian.junit.Arquillian;
import org.junit.After;
import org.junit.Before;
import org.junit.runner.RunWith;

@RunWith(Arquillian.class)
public abstract class TransactionalTestCase
{

    @Resource
    protected UserTransaction ut;
    
    protected TestData testData;

    @Before
    public void startTransaction() throws Exception
    {
        ut.begin();
        // Required by OpenJPA
        getEntityManager().getMetamodel();
    }
    
    @Before
    public void initTestData()
    {
        testData = new TestData(getEntityManager());
    }

    @After
    public void rollbackTransaction() throws Exception
    {
        ut.rollback();
    }

    @Inject private EntityManager entityManager;
    
    protected EntityManager getEntityManager()
    {
        return entityManager;
    }

}

==> deltaspike-2.0.1-source-release.zip: deltaspike-2.0.1/deltaspike/modules/data/impl/src/test/java/org/apache/deltaspike/data/test/TransactionalTestCase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.deltaspike.data.test;

import jakarta.annotation.Resource;
import jakarta.inject.Inject;
import jakarta.persistence.EntityManager;
import jakarta.transaction.UserTransaction;

import org.apache.deltaspike.data.test.util.TestData;
import org.jboss.arquillian.junit.Arquillian;
import org.junit.After;
import org.junit.Before;
import org.junit.runner.RunWith;

@RunWith(Arquillian.class)
public abstract class TransactionalTestCase
{

    @Resource
    protected UserTransaction ut;
    
    protected TestData testData;

    @Before
    public void startTransaction() throws Exception
    {
        ut.begin();
        // Required by OpenJPA
        getEntityManager().getMetamodel();
    }
    
    @Before
    public void initTestData()
    {
        testData = new TestData(getEntityManager());
    }

    @After
    public void rollbackTransaction() throws Exception
    {
        ut.rollback();
    }

    @Inject private EntityManager entityManager;
    
    protected EntityManager getEntityManager()
    {
        return entityManager;
    }

}
